@@ -47,12 +47,23 @@ class LaunchpadTracker:
 
     def find_oops_references(self, start_time, end_time, project=None,
         projectgroup=None):
+        """Find oops references from start_time to end_time.
+
+        :param project: Either None or a project name, or a list of projects.
+        :param projectgroup: Either None or a project group name or a list
+            of project group names.
+        """
         projects = set([])
         if project is not None:
-            projects.add(project)
+            if type(project) is not list:
+                project = [project]
+            projects.update(project)
         if projectgroup is not None:
-            [projects.add(lp_proj.name)
-                for lp_proj in self.lp.project_groups[projectgroup].projects]
+            if type(projectgroup) is not list:
+                projectgroup = [projectgroup]
+            for group in projectgroup:
+                [projects.add(lp_proj.name)
+                    for lp_proj in self.lp.project_groups[group].projects]
         result = set()
         lp_projects = self.lp.projects
         one_week = datetime.timedelta(weeks=1)
@@ -82,7 +93,7 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
         The following options must be supplied:
          --repo
 
-         And either
+         And at least one of either
          --project
          or
          --projectgroup
@@ -92,6 +103,8 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
 
         Will process every member project of launchpad-project.
 
+        --project and --projectgroup can be supplied multiple times.
+
         When run this program will ask Launchpad for OOPS references made since
         the last date it pruned up to, with an upper limit of one week from
         today. It then looks in the repository for all oopses created during
@@ -103,9 +116,9 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
         "Delete OOPS reports that are not referenced in a bug tracker."
     parser = optparse.OptionParser(
         description=description, usage=usage)
-    parser.add_option('--project',
+    parser.add_option('--project', action="append",
         help="Launchpad project to find references in.")
-    parser.add_option('--projectgroup',
+    parser.add_option('--projectgroup', action="append",
         help="Launchpad project group to find references in.")
     parser.add_option('--repo', help="Path to the repository to read from.")
     parser.add_option(
@@ -122,9 +135,6 @@ def main(argv=None, tracker=LaunchpadTracker, logging=logging):
             else:
                 raise ValueError(
                     'One of options %s must be supplied' % (optnames,))
-        elif len(present) != 1:
-            raise ValueError(
-                    'Only one of options %s can be supplied' % (optnames,))
     needed('repo')
     needed('project', 'projectgroup')
     logging.basicConfig(
